/**
 * Extract the prefix as a whole string from the number parts.
 *
 * @param valueParts the parts of the formatted number returmed from Intl.NumberFormat#formatToParts
 * @returns the prefix as a single string or an empty string.
 */
export declare const getPrefix: (valueParts: Intl.NumberFormatPart[]) => string;
/**
 * Extract the integer as a whole string from the number parts.
 *
 * @param valueParts the parts of the formatted number returmed from Intl.NumberFormat#formatToParts
 * @returns the integer as a single string or an empty string.
 */
export declare const getInteger: (valueParts: Intl.NumberFormatPart[]) => string;
/**
 * Get the decimal separator from the number parts.
 *
 * @param valueParts the parts of the formatted number returmed from Intl.NumberFormat#formatToParts
 * @returns the separator as a string or an empty string.
 */
export declare const getSeparator: (valueParts: Intl.NumberFormatPart[]) => string;
/**
 * Extract the fraction as a whole string from the number parts.
 *
 * @param valueParts the parts of the formatted number returmed from Intl.NumberFormat#formatToParts
 * @returns the fraction as a single string or an empty string.
 */
export declare const getFraction: (valueParts: Intl.NumberFormatPart[]) => string;
/**
 * Extract the suffix as a whole string from the number parts.
 *
 * @param valueParts the parts of the formatted number returmed from Intl.NumberFormat#formatToParts
 * @returns the suffix as a single string or an empty string.
 */
export declare const getSuffix: (valueParts: Intl.NumberFormatPart[]) => string;
/**
 * Compare the two string values and return the index from where there's a difference.
 *
 * @param value1 the numeric value to check, formatted as a string.
 * @param value2 the numeric value to check against, formatted as a string.
 * @returns the index of the difference. value1 is used as a reference.
 */
export declare const getComparisonDiffIndex: (value1: string, value2: string) => number;
/**
 * Get the sequence of '0' representing the muted digits. The number of muted digits is the difference between the two parameters nbDigits and maxDigits.
 *
 * @param nbDigits the number of digits of the number.
 * @param maxDigits the maximum of digits to display.
 * @returns a sequence of '0' or an empty string if maxDigits is less or equal to nbDigits.
 */
export declare const getMutedDigits: (nbDigits: number, maxDigits: number) => string;
/**
 * Get the font color based on the diff between the value and the previous value.
 *
 * @param positiveColor the color applied for a positive difference
 * @param negativeColor the color applied for a negative difference
 * @param value the value to check.
 * @param previousValue the previous value to check against.
 * @returns the CSS color, either the positive, the negative colors or 'inherit' if there is no difference or previous value is not provided.
 */
export declare const getDiffColor: (positiveColor: string, negativeColor: string, value: number, previousValue?: number | undefined) => string;
/**
 * Extract the span props to forward from the whole component props.
 *
 * @param props the whole component props.
 * @returns the HTML span element props.
 */
export declare const extractSpanProps: (props: any) => React.HTMLAttributes<HTMLSpanElement>;
