var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __spreadArray = (this && this.__spreadArray) || function (to, from) {
    for (var i = 0, il = from.length, j = to.length; i < il; i++, j++)
        to[j] = from[i];
    return to;
};
/**
 * Extract the prefix as a whole string from the number parts.
 *
 * @param valueParts the parts of the formatted number returmed from Intl.NumberFormat#formatToParts
 * @returns the prefix as a single string or an empty string.
 */
export var getPrefix = function (valueParts) {
    var prefixIndex = valueParts.findIndex(function (part) {
        return part.type === "integer" ||
            part.type === "group" ||
            part.type === "decimal" ||
            part.type === "fraction";
    });
    var prefixArray = prefixIndex > 0 ? valueParts.slice(0, prefixIndex) : [];
    return prefixArray
        .map(function (part) { return part.value; })
        .reduce(function (previousValue, value) { return previousValue + value; }, "")
        .trimStart();
};
/**
 * Extract the integer as a whole string from the number parts.
 *
 * @param valueParts the parts of the formatted number returmed from Intl.NumberFormat#formatToParts
 * @returns the integer as a single string or an empty string.
 */
export var getInteger = function (valueParts) {
    return valueParts
        .filter(function (part) { return part.type === "integer" || part.type === "group"; })
        .map(function (part) { return part.value; })
        .reduce(function (previousValue, value) { return previousValue + value; }, "");
};
/**
 * Get the decimal separator from the number parts.
 *
 * @param valueParts the parts of the formatted number returmed from Intl.NumberFormat#formatToParts
 * @returns the separator as a string or an empty string.
 */
export var getSeparator = function (valueParts) {
    return valueParts
        .filter(function (part) { return part.type === "decimal"; })
        .map(function (part) { return part.value; })
        .reduce(function (previousValue, value) { return previousValue + value; }, "");
};
/**
 * Extract the fraction as a whole string from the number parts.
 *
 * @param valueParts the parts of the formatted number returmed from Intl.NumberFormat#formatToParts
 * @returns the fraction as a single string or an empty string.
 */
export var getFraction = function (valueParts) {
    return valueParts
        .filter(function (part) { return part.type === "fraction"; })
        .map(function (part) { return part.value; })
        .reduce(function (previousValue, value) { return previousValue + value; }, "");
};
/**
 * Extract the suffix as a whole string from the number parts.
 *
 * @param valueParts the parts of the formatted number returmed from Intl.NumberFormat#formatToParts
 * @returns the suffix as a single string or an empty string.
 */
export var getSuffix = function (valueParts) {
    var suffixReverseIndex = __spreadArray([], valueParts).reverse()
        .findIndex(function (part) {
        return part.type === "integer" ||
            part.type === "group" ||
            part.type === "decimal" ||
            part.type === "fraction";
    });
    var suffixIndex = suffixReverseIndex > 0
        ? valueParts.length - suffixReverseIndex
        : valueParts.length;
    var suffixArray = suffixIndex < valueParts.length ? valueParts.slice(suffixIndex) : [];
    return suffixArray
        .map(function (part) { return part.value; })
        .reduce(function (previousValue, value) { return previousValue + value; }, "")
        .trimEnd();
};
var getNZeros = function (nbZeros) {
    return nbZeros > 0 ? String(Math.pow(10, nbZeros)).slice(1) : "";
};
/**
 * Compare the two string values and return the index from where there's a difference.
 *
 * @param value1 the numeric value to check, formatted as a string.
 * @param value2 the numeric value to check against, formatted as a string.
 * @returns the index of the difference. value1 is used as a reference.
 */
export var getComparisonDiffIndex = function (value1, value2) {
    if (value1.length !== value2.length) {
        return value2.length > value1.length ? value1.length : 0;
    }
    var index = value1
        .split("")
        .findIndex(function (val, i) { return val !== value2.charAt(i); });
    return index < 0 ? value1.length : index;
};
/**
 * Get the sequence of '0' representing the muted digits. The number of muted digits is the difference between the two parameters nbDigits and maxDigits.
 *
 * @param nbDigits the number of digits of the number.
 * @param maxDigits the maximum of digits to display.
 * @returns a sequence of '0' or an empty string if maxDigits is less or equal to nbDigits.
 */
export var getMutedDigits = function (nbDigits, maxDigits) {
    return getNZeros(maxDigits - nbDigits);
};
/**
 * Get the font color based on the diff between the value and the previous value.
 *
 * @param positiveColor the color applied for a positive difference
 * @param negativeColor the color applied for a negative difference
 * @param value the value to check.
 * @param previousValue the previous value to check against.
 * @returns the CSS color, either the positive, the negative colors or 'inherit' if there is no difference or previous value is not provided.
 */
export var getDiffColor = function (positiveColor, negativeColor, value, previousValue) {
    if (!previousValue) {
        return "inherit";
    }
    return value > previousValue
        ? positiveColor
        : value < previousValue
            ? negativeColor
            : "inherit";
};
/* eslint-disable @typescript-eslint/no-unsafe-assignment, @typescript-eslint/no-unsafe-member-access, @typescript-eslint/explicit-module-boundary-types, @typescript-eslint/no-explicit-any */
/**
 * Extract the span props to forward from the whole component props.
 *
 * @param props the whole component props.
 * @returns the HTML span element props.
 */
export var extractSpanProps = function (props) {
    var cleanedProps = __assign({}, props);
    delete cleanedProps.value;
    delete cleanedProps.locales;
    delete cleanedProps.options;
    delete cleanedProps.smallDecimals;
    delete cleanedProps.privacyMode;
    delete cleanedProps.privacyShadowColor;
    delete cleanedProps.previousValue;
    delete cleanedProps.positiveColor;
    delete cleanedProps.negativeColor;
    delete cleanedProps.significantDecimalDigits;
    delete cleanedProps.showMutedDecimals;
    delete cleanedProps.maxDecimalDigits;
    return cleanedProps;
};
/* eslint-enable @typescript-eslint/no-unsafe-assignment, @typescript-eslint/no-unsafe-member-access, @typescript-eslint/explicit-module-boundary-types, @typescript-eslint/no-explicit-any */
